Turn trellis off for 1-pass encodes

An earlier commit turned trellis optimization on for 1-pass
encoding, which broke a few tests. This patch reverts to
no trellis for 1-pass encoding.
Later we need to investigate the source of the incompatibility.

STATS_CHANGED

BUG=aomedia:2320
BUG=aomedia:2321
BUG=aomedia:2322

Change-Id: Ib321a550b6eb099ba582cf756d1f0e335f94347c
diff --git a/av1/encoder/speed_features.c b/av1/encoder/speed_features.c
index b5121f0..70a4154 100644
--- a/av1/encoder/speed_features.c
+++ b/av1/encoder/speed_features.c
@@ -833,9 +833,10 @@
   // so make sure they are always turned off.
   if (oxcf->pass == 1) sf->optimize_coefficients = NO_TRELLIS_OPT;
 
   // No recode for 1 pass.
   if (oxcf->pass == 0) {
     sf->recode_loop = DISALLOW_RECODE;
+    sf->optimize_coefficients = NO_TRELLIS_OPT;
   }
   // FIXME: trellis not very efficient for quantization matrices
   if (oxcf->using_qm) sf->optimize_coefficients = NO_TRELLIS_OPT;
@@ -833,9 +833,10 @@
   if (oxcf->pass == 1) sf->optimize_coefficients = NO_TRELLIS_OPT;
 
-  // No recode for 1 pass.
+  // No recode or trellis for 1 pass.
   if (oxcf->pass == 0) {
     sf->recode_loop = DISALLOW_RECODE;